var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import styled, { css } from 'styled-components';
import { isEmpty } from 'lodash-es';
import { colorUtil } from '../../../../utils/ColorUtil';
import { textUtil } from '../../../../utils/TextUtil';
import theme from '../../../../theme';
function Title(props) {
    const { size, content, color, partialColors, isVisible } = props, remain = __rest(props, ["size", "content", "color", "partialColors", "isVisible"]);
    const texts = textUtil.processTextWithNewlines(content);
    if (!isVisible)
        return null;
    return (_jsx(TitleStyled, Object.assign({}, props, { children: texts === null || texts === void 0 ? void 0 : texts.map((text, i) => {
            const replacedText = colorUtil.applyColorsToText(text, partialColors);
            /** 텍스트가 가공된 경우 */
            if (!isEmpty(replacedText)) {
                const innerHtml = { __html: replacedText };
                return (_jsxs(_Fragment, { children: [_jsx("span", { dangerouslySetInnerHTML: innerHtml }, i), _jsx("br", {})] }));
            }
            /** 텍스트가 가공되지 않은 경우 */
            return (_jsxs(_Fragment, { children: [_jsx("span", { children: text }, i), _jsx("br", {})] }));
        }) })));
}
Title.defaultProps = {
    size: 'xl',
    content: 'Title Title\nTitle Title Title',
    color: theme.colors.black,
    partialColors: [theme.colors.black],
    fontWeight: 'bold',
    highlight: {
        height: 28,
        color: theme.colors.gray500,
        isVisible: false,
    },
    isMobile: false,
    isVisible: true,
    isFullWidth: false,
    textAlign: 'left',
};
export default Title;
const highlightStyles = css `
  display: inline;
  box-shadow: inset 0 -${props => { var _a; return (_a = props.highlight) === null || _a === void 0 ? void 0 : _a.height; }}px 0 ${props => { var _a; return (_a = props.highlight) === null || _a === void 0 ? void 0 : _a.color; }};
`;
const headingCommonStyles = css `
  display: inline-block;
  text-align: ${props => props.textAlign};
  color: ${props => props.color};
  margin: 0;
  width: auto;
  height: auto;
  font-family: ${props => (props.fontWeight === 'bold' ? `${theme.fontFamily.bold}` : `${theme.fontFamily.normal}`)};
  font-weight: normal;
  span {
    ${props => { var _a; return ((_a = props.highlight) === null || _a === void 0 ? void 0 : _a.isVisible) && highlightStyles; }}
  }
`;
const xlargeFontStyles = css `
  font-size: ${props => (!props.isMobile ? '58px' : '36px')};
  letter-spacing: ${props => (!props.isMobile ? '-0.7px' : '-0.6px')};
  line-height: 1.25em;
`;
const largeFontStyles = css `
  font-size: ${props => (!props.isMobile ? '42px' : '28px')};
  letter-spacing: ${props => (!props.isMobile ? '-0.6px' : '-0.5px')};
  line-height: 1.25em;
`;
const mediumFontStyles = css `
  font-size: ${props => (!props.isMobile ? '32px' : '24px')};
  letter-spacing: ${props => (!props.isMobile ? '-0.5px' : '-0.4px')};
  line-height: 1.25em;
`;
const smallFontStyles = css `
  font-size: ${props => (!props.isMobile ? '24px' : '18px')};
  letter-spacing: ${props => (!props.isMobile ? '-0.4px' : '-0.3px')};
  line-height: 1.25em;
`;
export const TitleStyled = styled.h1 `
  ${headingCommonStyles}
  ${props => props.size === 'xl' && xlargeFontStyles}
  ${props => props.size === 'lg' && largeFontStyles}
  ${props => props.size === 'md' && mediumFontStyles}
  ${props => props.size === 'sm' && smallFontStyles}
  margin: ${props => props.margin};
  padding: ${props => props.padding};
  width: ${props => (props.isFullWidth ? '100%' : 'auto')};
`;
