var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import styled, { css } from 'styled-components';
import theme from '../../../../theme';
import Icon from '../../atoms/Icon';
import { isEmpty } from 'lodash-es';
export default function Button(props) {
    const { content, icon, size, color, iconPosition, isLoading, isDisabled, onClick } = props, remain = __rest(props, ["content", "icon", "size", "color", "iconPosition", "isLoading", "isDisabled", "onClick"]);
    const iconGap = size === 'sm' ? 4 : size === 'md' ? 8 : size === 'lg' ? 8 : 12;
    const iconSize = size === 'sm' ? 16 : 24;
    if (isLoading)
        return _jsx(ButtonStyled, Object.assign({}, props, { children: "Loading..." }));
    return (_jsxs(ButtonStyled, Object.assign({ onClick: onClick, disabled: isDisabled }, props, { children: [!isEmpty(icon) && iconPosition === 'left' && _jsx(Icon, { name: icon, size: iconSize, color: color }), content && (_jsx(TextStyled, Object.assign({ gap: iconGap, icon: icon, position: iconPosition }, { children: content }))), !isEmpty(icon) && iconPosition === 'right' && _jsx(Icon, { name: icon, size: iconSize, color: color })] })));
}
Button.defaultProps = {
    buttonType: 'solid',
    size: 'md',
    content: 'Button',
    backgroundColor: theme.colors.black,
    color: theme.colors.white,
    border: {
        width: 0,
        radius: 12,
        color: null,
    },
    icon: 'home',
    iconPosition: 'left',
    isLoading: false,
    isDisabled: false,
    isFullWidth: false,
};
const buttonBlackLayerStyle = css `
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: ${props => { var _a; return (_a = props.border) === null || _a === void 0 ? void 0 : _a.radius; }}px;
`;
const solidStyle = css `
  border: none;
  background: ${props => props.backgroundColor};
  position: relative;

  &:hover {
    &::after {
      ${buttonBlackLayerStyle}
    }
  }

  &:disabled {
    background: none;
    background-color: ${theme.colors.gray200};
    color: ${theme.colors.gray500};
  }
`;
const ghostStyle = css `
  border-width: 0px;
  position: relative;
  background-color: transparent;

  &:hover {
    &::after {
      ${buttonBlackLayerStyle}
    }
  }

  &:disabled {
    background-color: ${theme.colors.gray200};
    color: ${theme.colors.gray500};
  }
`;
const linkStyle = css `
  padding: 0;
  background-color: transparent;
  cursor: pointer;
  border-width: 0px;

  ${props => props.size === 'xl' &&
    `
        font-size: 24px;
        letter-spacing: -0.4px;
        line-height: 32px;
    `};
  ${props => props.size === 'lg' &&
    `
        font-size: 18px;
        letter-spacing: -0.3px;
        line-height: 28px;
    `};
  ${props => props.size === 'md' &&
    `
        font-size: 16px;
        letter-spacing: -0.4px;
        line-height: 24px;
    `};
  ${props => props.size === 'sm' &&
    `
        font-size: 12px;
        letter-spacing: -0.2px;
        line-height: 16px;
    `};

  &:hover {
    opacity: 0.6;
  }

  &:disabled {
    opacity: 0.3;
  }
`;
const outlineStyle = css `
  position: relative;
  border-buttontype: solid;
  border-width: ${props => { var _a; return ((_a = props.border) === null || _a === void 0 ? void 0 : _a.width) || 1; }}px;
  border-radius: ${props => { var _a; return ((_a = props.border) === null || _a === void 0 ? void 0 : _a.radius) || 12; }}px;
  border-color: ${props => props.color || theme.colors.black};
  color: ${props => props.color || theme.colors.black};
  background-color: transparent;

  &:hover {
    &::after {
      ${buttonBlackLayerStyle}
    }
  }

  &:disabled {
    background-color: ${theme.colors.gray200};
    color: ${theme.colors.gray500};
    border-color: ${theme.colors.gray500};
  }
`;
const ButtonStyled = styled.button `
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: 'Pretendard Bold';
  color: ${props => props.color};
  background: none;
  cursor: pointer;
  border-radius: 12px;
  width: ${props => (props.isFullWidth ? '100%' : 'auto')};

  margin: ${props => props.margin};

  ${props => props.size === 'sm' &&
    `
        padding: 8px 12px;
        font-size: 12px;
        line-height: 16px;
        letter-spacing: -0.2px;
    `};

  ${props => props.size === 'md' &&
    `
        padding: 12px 20px;
        font-size: 16px;
        line-height: 24px;
        letter-spacing: -0.3px;
    `};

  ${props => props.size === 'lg' &&
    `
        padding: 15px 24px;
        font-size: 18px;
        line-height: 26px;
        letter-spacing: -0.3px;
    `};

  ${props => props.size === 'xl' &&
    `
        padding: 19px 28px;
        font-size: 18px;
        line-height: 26px;
        letter-spacing: -0.3px;
    `};

  ${props => props.buttonType === 'solid' && solidStyle};
  ${props => props.buttonType === 'ghost' && ghostStyle};
  ${props => props.buttonType === 'link' && linkStyle};
  ${props => props.buttonType === 'outline' && outlineStyle};
`;
const TextStyled = styled.span `
  color: inherit;
  white-space: nowrap;
  margin-left: ${props => (props.icon && props.position === 'left' ? props.gap : 0)}px;
  margin-right: ${props => (props.icon && props.position === 'right' ? props.gap : 0)}px;
`;
