import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import styled from 'styled-components';
import { isEmpty } from 'lodash-es';
import { Stack } from '../../../layout';
import Button from '../../molecules/Button/Button';
import theme from '../../../../theme';
export default function Header(props) {
    const { menus, menuColor, menuGap, menuButtonGap, borderBottomColor, logo, logoHeight, headerBackground, buttons, isMobile } = props;
    const direction = !isMobile ? 'row' : 'column';
    return (_jsxs(Box, Object.assign({ borderBottomColor: borderBottomColor, headerBackground: headerBackground, isMobile: isMobile }, { children: [_jsx(LeftArea, { children: _jsx(Logo, { src: logo, alt: "\uB85C\uACE0", height: logoHeight }) }), _jsxs(RightArea, { children: [!isMobile && (_jsx(Stack, Object.assign({ direction: direction, gap: menuGap }, { children: menus.map((menu, index) => {
                            const { text, href, isActive } = menu;
                            return (_jsx(Menu, Object.assign({ href: href, menuColor: menuColor, isActive: isActive }, { children: text }), index));
                        }) }))), !isEmpty(buttons) && (_jsx(RightButtonArea, Object.assign({ menuButtonGap: menuButtonGap }, { children: _jsx(Stack, Object.assign({ direction: "row", gap: 24, alignItems: "center" }, { children: buttons })) })))] })] })));
}
Header.defaultProps = {
    borderBottomColor: '#8D8D8D',
    headerBackground: '#f9f9f9',
    menuColor: theme.colors.black,
    menus: [
        { text: '메뉴1', href: null, isActive: true },
        { text: '메뉴2', href: null, isActive: true },
        { text: '메뉴3', href: null, isActive: true },
    ],
    menuGap: 56,
    menuButtonGap: 32,
    logo: 'https://codeindesign.s3.ap-northeast-2.amazonaws.com/CodeInDesign+Logo.png',
    logoHeight: 32,
    buttons: [_jsx(Button, {}), _jsx(Button, {})],
    isMobile: false,
};
const Box = styled.div `
  width: 100%;
  padding: ${props => (!props.isMobile ? '17px 32px' : '19px 16px')};
  display: flex;
  justify-content: space-between;
  align-items: center;
  background-color: ${props => props.headerBackground};
  border-bottom: 1px solid ${props => props.borderBottomColor};
`;
const Menu = styled.a `
  cursor: pointer;
  color: ${props => props.menuColor};
  text-decoration: none;
  font-size: 18px;
  font-family: 'Pretendard Regular';
  font-weight: ${props => (props.isActive ? 'bold' : 'normal')};

  &:hover {
    color: white;
  }
`;
const RightArea = styled.div `
  display: flex;
  align-items: center;
`;
const RightButtonArea = styled.div `
  display: flex;
  height: 100%;
  align-items: center;
  margin-left: ${props => props.menuButtonGap}px;
`;
const LeftArea = styled.div `
  display: flex;
  align-items: center;
`;
const Logo = styled.img `
  height: ${props => props.logoHeight}px;
  object-fit: contain;
`;
