var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from 'axios';
class Api {
    constructor() {
        this.loginPath = '/tutors/login';
        this.loginApiPath = '/api/v1/auth/login';
        this.tokenRefreshApiPath = '/api/v1/auth/token/refresh';
        this.API_ROOT = process.env.NODE_ENV === 'production' ? 'https://api.com' : 'http://localhost:8080';
        this.api = axios.create({
            baseURL: this.API_ROOT,
            timeout: 10000,
        });
        this.api.interceptors.request.use(config => {
            process.env.NODE_ENV !== 'production' && console.log(`API 요청 (액세스 토큰): ${this.accessToken}`);
            if (this.accessToken)
                config.headers['Authorization'] = `Bearer ${this.accessToken}`;
            return config;
        }, e => e);
        this.api.interceptors.response.use(res => res, (err) => __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c, _d;
            const shouldRefreshToken = err.config && err.response && err.response.status === 401 && !err.config.__isRetry;
            const shouldShowServerError = err.response.status !== 500;
            if (shouldRefreshToken) {
                const errorCode = (_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.errorCode;
                if (errorCode === 'ACCESS_TOKEN_EXPIRED' || errorCode === 'NO_ACCESS_TOKEN') {
                    return yield this.silentRefreshTokenAndRetry(err);
                }
                if (errorCode === 'REFRESH_TOKEN_EXPIRED' || errorCode === 'NO_REFRESH_TOKEN') {
                    return (window.location.href = this.loginPath);
                }
            }
            if (shouldShowServerError) {
                const errorMessage = (_d = (_c = err.response) === null || _c === void 0 ? void 0 : _c.data) === null || _d === void 0 ? void 0 : _d.message;
                errorMessage && sessionStorage.setItem('errorMessage', errorMessage);
            }
            throw err;
        }));
    }
    get(path, params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.api.get(path, { params });
        });
    }
    post(path, requestBody) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.api.post(path, requestBody);
        });
    }
    put(path, requestBody) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.api.put(path, requestBody);
        });
    }
    patch(path, requestBody) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.api.patch(path, requestBody);
        });
    }
    delete(path) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.api.delete(path);
        });
    }
    refreshToken() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { result } = (yield this.post(this.tokenRefreshApiPath)).data;
                this.setAccessToken(result === null || result === void 0 ? void 0 : result.accessToken);
                return this.accessToken;
            }
            catch (e) {
                console.log('토큰 갱신에 실패하여 재로그인이 필요합니다.');
                window.location.href = this.loginPath;
                return;
            }
        });
    }
    silentRefreshTokenAndRetry(err) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const oldAccessToken = this.accessToken;
                err.config.__isRetry = true;
                const originalRequestConfig = err.config;
                delete originalRequestConfig.headers['Authorization'];
                const newAccessToken = yield this.refreshToken();
                originalRequestConfig.headers['Authorization'] = `Baerer ${newAccessToken}`;
                process.env.NODE_ENV !== 'production' && console.log(`액세스 토큰이 갱신되었습니다.\nbefore: ${oldAccessToken}\n\nafter: ${newAccessToken}`);
                process.env.NODE_ENV !== 'production' && console.log(`토큰 갱신 후 이전 요청을 다시 시도하겠습니다. ${originalRequestConfig.url}`);
                return yield this.api.request(originalRequestConfig);
            }
            catch (e) {
                process.env.NODE_ENV !== 'production' && console.log('silentRefreshTokenAndRetry 실패', e.message);
                throw e;
            }
        });
    }
    login(payload) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { result } = (yield this.post(this.loginApiPath, payload)).data;
                this.setAccessToken(result === null || result === void 0 ? void 0 : result.accessToken);
                return true;
            }
            catch (e) {
                console.error(e);
                return false;
            }
        });
    }
    setAccessToken(token) {
        if (!token) {
            if (process.env.NODE_ENV !== 'production')
                console.log('새로운 액세스 토큰 등록에 실패했습니다. 토큰이 전달되지 않았습니다.');
            return;
        }
        this.accessToken = token;
        process.env.NODE_ENV !== 'production' && console.log(`새로운 액세스 토큰이 등록되었습니다. ${this.accessToken}`);
    }
    getAccessToken() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.accessToken)
                yield this.refreshToken();
            return this.accessToken;
        });
    }
    setLoginPath(loginPath) {
        this.loginPath = loginPath;
    }
}
const API = new Api();
export default API;
